Rohde & Schwarz NGx Power Supply RsNgx instrument driver.

Supported instruments: NGU, NGL, NGM, NGP

The package is hosted here: https://pypi.org/project/RsNgx/

Documentation: https://RsNgx.readthedocs.io/

Examples: https://github.com/Rohde-Schwarz/Examples/tree/main/Misc/Python/RsNgx_ScpiPackage

----------------------------------------------------------------------------------

Release Notes:

Latest release notes summary: Rebuilt with new driver core

Version 3.1.0.49

- Rebuilt with new driver core

Version 3.1.0.48

- Update for NGP800 FW 2.015

Version 3.0.0.39

- First released version for NGU FW 3.0